@@ -20,13 +20,15 @@
 |![Typescript Logo](https://docs.aws.amazon.com/cdk/api/latest/img/typescript32.png) Typescript|`@aws-solutions-constructs/aws-eventbridge-lambda`|
 |![Java Logo](https://docs.aws.amazon.com/cdk/api/latest/img/java32.png) Java|`software.amazon.awsconstructs.services.eventbridgelambda`|
 
+## Overview
+
 This AWS Solutions Construct implements an AWS EventBridge rule and an AWS Lambda function.
 
 Here is a minimal deployable pattern definition:
 
 Typescript
 
-```javascript
+```python
 import { Construct } from 'constructs';
 import { Stack, StackProps, Duration } from 'aws-cdk-lib';
 import { EventbridgeToLambdaProps, EventbridgeToLambda } from '@aws-solutions-constructs/aws-eventbridge-lambda';
@@ -138,7 +140,7 @@ Out of the box implementation of the Construct without any override will set the
 ---
 
 
-© Copyright 2021 Amazon.com, Inc. or its affiliates. All Rights Reserved.
+© Copyright 2022 Amazon.com, Inc. or its affiliates. All Rights Reserved.
 '''
 import abc
 import builtins
@@ -150,6 +152,8 @@ import jsii
 import publication
 import typing_extensions
 
+from typeguard import check_type
+
 from ._jsii import *
 
 import aws_cdk.aws_events
@@ -167,11 +171,11 @@ class EventbridgeToLambda(
         scope: aws_cdk.core.Construct,
         id: builtins.str,
         *,
-        event_rule_props: aws_cdk.aws_events.RuleProps,
-        event_bus_props: typing.Optional[aws_cdk.aws_events.EventBusProps] = None,
+        event_rule_props: typing.Union[aws_cdk.aws_events.RuleProps, typing.Dict[str, typing.Any]],
+        event_bus_props: typing.Optional[typing.Union[aws_cdk.aws_events.EventBusProps, typing.Dict[str, typing.Any]]] = None,
         existing_event_bus_interface: typing.Optional[aws_cdk.aws_events.IEventBus] = None,
         existing_lambda_obj: typing.Optional[aws_cdk.aws_lambda.Function] = None,
-        lambda_function_props: typing.Optional[aws_cdk.aws_lambda.FunctionProps] = None,
+        lambda_function_props: typing.Optional[typing.Union[aws_cdk.aws_lambda.FunctionProps, typing.Dict[str, typing.Any]]] = None,
     ) -> None:
         '''
         :param scope: - represents the scope for all the resources.
@@ -185,6 +189,10 @@ class EventbridgeToLambda(
         :access: public
         :summary: Constructs a new instance of the EventbridgeToLambda class.
         '''
+        if __debug__:
+            type_hints = typing.get_type_hints(EventbridgeToLambda.__init__)
+            check_type(argname="argument scope", value=scope, expected_type=type_hints["scope"])
+            check_type(argname="argument id", value=id, expected_type=type_hints["id"])
         props = EventbridgeToLambdaProps(
             event_rule_props=event_rule_props,
             event_bus_props=event_bus_props,
@@ -226,11 +234,11 @@ class EventbridgeToLambdaProps:
     def __init__(
         self,
         *,
-        event_rule_props: aws_cdk.aws_events.RuleProps,
-        event_bus_props: typing.Optional[aws_cdk.aws_events.EventBusProps] = None,
+        event_rule_props: typing.Union[aws_cdk.aws_events.RuleProps, typing.Dict[str, typing.Any]],
+        event_bus_props: typing.Optional[typing.Union[aws_cdk.aws_events.EventBusProps, typing.Dict[str, typing.Any]]] = None,
         existing_event_bus_interface: typing.Optional[aws_cdk.aws_events.IEventBus] = None,
         existing_lambda_obj: typing.Optional[aws_cdk.aws_lambda.Function] = None,
-        lambda_function_props: typing.Optional[aws_cdk.aws_lambda.FunctionProps] = None,
+        lambda_function_props: typing.Optional[typing.Union[aws_cdk.aws_lambda.FunctionProps, typing.Dict[str, typing.Any]]] = None,
     ) -> None:
         '''
         :param event_rule_props: User provided eventRuleProps to override the defaults. Default: - None
@@ -247,6 +255,13 @@ class EventbridgeToLambdaProps:
             event_bus_props = aws_cdk.aws_events.EventBusProps(**event_bus_props)
         if isinstance(lambda_function_props, dict):
             lambda_function_props = aws_cdk.aws_lambda.FunctionProps(**lambda_function_props)
+        if __debug__:
+            type_hints = typing.get_type_hints(EventbridgeToLambdaProps.__init__)
+            check_type(argname="argument event_rule_props", value=event_rule_props, expected_type=type_hints["event_rule_props"])
+            check_type(argname="argument event_bus_props", value=event_bus_props, expected_type=type_hints["event_bus_props"])
+            check_type(argname="argument existing_event_bus_interface", value=existing_event_bus_interface, expected_type=type_hints["existing_event_bus_interface"])
+            check_type(argname="argument existing_lambda_obj", value=existing_lambda_obj, expected_type=type_hints["existing_lambda_obj"])
+            check_type(argname="argument lambda_function_props", value=lambda_function_props, expected_type=type_hints["lambda_function_props"])
         self._values: typing.Dict[str, typing.Any] = {
             "event_rule_props": event_rule_props,
         }
